# Copyright (C) 2010 Alejandro Ochoa, Singh Research Group, Princeton University
# This file is part of dPUC.
# dPUC is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
# dPUC is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
# You should have received a copy of the GNU General Public License along with dPUC.  If not, see <http://www.gnu.org/licenses/>.

package FilePaths;
use strict;

# in general, variables declared using 'my' are only auxiliary, used within this package, and can be removed if the end user finds it more convenient
# however, variables declared using 'our' are used by external programs, and they must be present!

### PARAMETERS ###

our $timeout = 60; # default lp_solve timeout in seconds
our $comp = 'gzip'; # whether to use compression or not (and what kind.  Options are '', 'gzip', and 'bzip').  Note that 'bzip' uses the command line, and should not work on windows (or other non-Unices).  'gzip' uses a package that should be portable, but I don't know for sure.  An empty string will produce uncompressed output.  Note that output to STDOUT is never compressed, even if this is set.

### EXTERNAL PROGRAMS/DATA ###
# paths should be set by user, these are the values that work for me...
# $hmmpfam and $lpSolve have to be set
# $pfamLs and $pfamFs have to be set to run against HMMER, the other files are not necessary unless the user wants to re-parse the local files

our $hmmpfam = 'hmmpfam'; # HMMER executable
our $lpSolve = 'lp_solve'; # lp_solve executable

# source Pfam files
my $pfamDir = '/home/viiia/dbs/pfam/23/';
our $pfamFs = $pfamDir.'Pfam_fs'; # local
our $pfamLs = $pfamDir.'Pfam_ls'; # glocal
our $pfamASeed = $pfamDir.'Pfam-A.seed';
our $pfamAFull = $pfamDir.'Pfam-A.full';
our $pfamC = $pfamDir.'Pfam-C'; # for clans mapping

### LOCAL DATA ###
# this is all included in the distribution, most people won't need to change them

# PFAM PARSED
my $pfamParsedDir = 'pfam/';
# ... from PfamASeed
our $pfamName = $pfamParsedDir.'name.txt'; # PFAM accession's name
our $pfamGa = $pfamParsedDir.'GA.txt'; # PFAM gathering threshonds
our $pfamOrder = $pfamParsedDir.'order.txt'; # Order of scoring (globalfirst, localfirst, byscore)
our $pfamNesting = $pfamParsedDir.'nesting.txt'; # maps accession to a semicolon-delimited list of accessions that are allowed to overlap (nesting)
# ... from PfamC
our $pfamClans = $pfamParsedDir.'clans.txt'; # only Clans file that maps family accessions, to clan accessions
# ... from PfamAFull
our $pfamProt2hits = $pfamParsedDir.'prot2hits.txt'; # a Hits file, maps proteins to full hits.  Does not map pfam accessions first!
our $pfamArchesExact = $pfamParsedDir.'arches.exact.txt'; # a hash file, lists all architectures observed in Pfam (from prots2hits above, ultimately from Pfam-A.full) and their number of instances.  Architectures are ordered lists of accessions, this is a very exact and rigid definition

# CONTEXT NETWORK
my $contextNetDir = 'contextNet/';
our $dt2E = $contextNetDir.'dt2E.txt'; # table with -log(P) values, used later on in calculation of negative context scores
our $dt2dt2S = $contextNetDir.'dt2dt2S.txt'; # simple network, for easy parsing and computer manipulation

1;
