# Copyright (C) 2010 Alejandro Ochoa, Singh Research Group, Princeton University
# This file is part of dPUC.
# dPUC is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
# dPUC is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
# You should have received a copy of the GNU General Public License along with dPUC.  If not, see <http://www.gnu.org/licenses/>.

use lib '.';
use General;
use FilePaths;
use ParseAln;
use ContextDaemon;
use strict;

# input
my ($fiSeq, $fo, $Ecut) = @ARGV;

# usage, if called with "help" flag as first argument
my $usage = qq{usage: perl -w contextRunAll.pl [<fiSeq> <fo> <Ecut>]
    - <fiSeq> is the input sequence file path, FASTA format, may be multiple sequences, may be compressed.  If not specified, or if equal to '-', it uses standard input.
    - <fo> is the output file.  Will be compressed if the option is set in FilePaths.pm.  If not specified, or if equal to '-', it uses standard output.
    - <Ecut> is the E-value threshold for the candidate domains (default E <= 1).
};
die $usage if defined $fiSeq && ($fiSeq eq '-h' || $fiSeq eq '--help');

# input defaults
$fiSeq = '-' unless defined $fiSeq;
$fo = '-' unless defined $fo;
$Ecut = 1 unless defined $Ecut;

# prepare output
my $fho = General::getOutFh($fo, $FilePaths::comp);

# parse input into sequence hashes
my ($id2seq, $ids) = ParseAln::fastaInNonAlnHash($fiSeq);
# start running each sequence in file, in original order
foreach my $id (@$ids) {
    # get sequence of this ID
    my $seq = $id2seq->{$id};
    
    # do all processing by calling this one function
    # output is an array of very different things, but we don't need to name them all, they're in the same order as the printing function wants them.
    my (@output) = ContextDaemon::doSeqAll($id, $seq, $Ecut);
    # print predictions and stats to output
    ContextDaemon::printOutputText($fho, $id, $Ecut, @output);
}
