# Copyright (C) 2010 Alejandro Ochoa, Singh Research Group, Princeton University
# This file is part of dPUC.
# dPUC is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
# dPUC is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
# You should have received a copy of the GNU General Public License along with dPUC.  If not, see <http://www.gnu.org/licenses/>.

use lib '.';
use General;
use FilePaths;
use strict;

# gets the most useful PFAM annotation data from this complicated file and stores it into hashes that we can easily access when we need them
# this sub saves the hashes into tab-delimited text files.

# define hash structures
my %acc2name;
my %acc2ga; # Gathering thresholds.  Order: ls sequence, ls domain, fs sequence, fs domain.
my %acc2order; # Order of scoring (globalfirst, localfirst, byscore)
my %acc2nesting; # maps accession to a semicolon-delimited list of accessions that are allowed to overlap (nesting)

# a temporary variable that holds the current accession, so everything else can be mapped
my $acc = '';
my $name = ''; # name comes before accession, stupid, but we have to remember it and defer mapping of this one by one line...
my $nesting = ''; # list of domains that can nest, many lines, but also may be repeated :(

# open file, start reading
my $fhi = General::getInFh($FilePaths::pfamASeed);
while (<$fhi>) {
    if ( my ($type, $s) = /^\#=GF (\w+)\s+(.+)$/ ) { # things we're parsing for... many lines are not interesting
	if ($type eq 'ID') { $name = $s; }
	elsif ($type eq 'AC') {
	    $acc = $s; # read new accession
	    $acc =~ s/\.\d+$//; # remove version digits
	    $acc2name{$acc} = $name; # name gets mapped here
	}
	elsif ($type eq 'GA') { $acc2ga{$acc} = $s; }
	elsif ($type eq 'AM') { $acc2order{$acc} = $s; }
	elsif ($type eq 'NE') { $nesting .= $s unless $nesting =~ /$s/; } # concatenate unless this accession is already in list
    }
    elsif (/^\/\/$/) {
	# this implies the end of the entry, mandatory, so we know to save our buffers
	# don't store blank elements
	if ($nesting) {
	    $nesting =~ s/;$//; # remove last semicolon
	    $acc2nesting{$acc} = $nesting; # save
	    $nesting = ''; # clear so concatenation still works
	}
    }
}
close $fhi;

# now save hashes into files
General::printHashFile($FilePaths::pfamName, \%acc2name, 'gzip');
General::printHashFile($FilePaths::pfamGa, \%acc2ga, 'gzip');
General::printHashFile($FilePaths::pfamOrder, \%acc2order, 'gzip');
General::printHashFile($FilePaths::pfamNesting, \%acc2nesting, 'gzip');
